ESCHR: A hyperparameter-randomized ensemble approach for robust clustering across diverse datasets
==============================================================================================

Overview of Algorithm:
----------------------

.. image:: ../figure.png
   :alt: figure

Quick Start
-----------

You can try out the method without needing to install ESCHR locally with this `example jupyter notebook on Google Colab <./docs/notebooks/paul15_mouse_hematopoiesis.ipynb>`_.


.. toctree::
   :caption: Main
   :maxdepth: 2
   :hidden:

   installation
   example
   api
   changelog
   references

.. toctree::
   :caption: Walkthroughs
   :maxdepth: 2
   :hidden:

   notebooks/paul15_mouse_hematopoiesis
